@@ -243,13 +243,13 @@ EditText <- function(txt, read.only=FALSE, win.title="View Text",
   tclServiceMode(TRUE)
 
   if (!read.only) {
-    tkbind("Text", "<Control-s>", SaveAs)
-    tkbind("Text", "<Control-z>", EditUndo)
-    tkbind("Text", "<Control-y>", EditRedo)
-    tkbind("Text", "<Control-v>", EditPaste)
-    tkbind("Text", "<Control-l>", ClearConsole)
+    tkbind("Text", "<Control-KeyPress-s>", SaveAs)
+    tkbind("Text", "<Control-KeyPress-z>", EditUndo)
+    tkbind("Text", "<Control-KeyPress-y>", EditRedo)
+    tkbind("Text", "<Control-KeyPress-v>", EditPaste)
+    tkbind("Text", "<Control-KeyPress-l>", ClearConsole)
   }
-  tkbind("Text", "<Control-a>", EditSelectAll)
+  tkbind("Text", "<Control-KeyPress-a>", EditSelectAll)
 
   tkbind(tt, "<Destroy>", function() tclvalue(tt.done.var) <- 1)
 
